%define radius_rel 0
%define radius_maj 9
%define radius_min 3
%define radius_rev 20040318
%define ssl_ver 0.9.7c

Summary:     An RFC-compatible RADIUS server
Name:        freeradius
Version:     %{radius_rel}.%{radius_maj}.%{radius_min}
Release:     %{radius_rev}.pp
License:     GPL
Group:       System Environment/Daemons
Source0:     ftp://ftp.freeradius.org/pub/radius/CVS-snapshots/freeradius-snapshot-%{radius_rev}.tar.gz
Source1:     http://www.openssl.org/source/openssl-%{ssl_ver}.tar.gz
Patch0:      freeradius-openssl.patch
URL:         http://www.freeradius.org/
Buildroot:   /var/tmp/freeradius-root
Vendor:      Peter Pramberger
Packager:    Peter Pramberger <peter.pramberger@1012surf.net>
Requires:    openssl openldap cyrus-sasl pam perl gdbm db3 ucd-snmp
Requires:    krb5-libs
Provides:    freeradius.pp
Obsoletes:   cistron-radius radiator
Prereq:      /bin/bash /sbin/ldconfig
BuildPrereq: gcc >= 2.96 /bin/mkdir /usr/bin/make /usr/bin/install perl
BuildPrereq: openssl-devel pam-devel gdbm-devel db3-devel openldap-devel
BuildPrereq: krb5-devel mysql-devel postgresql-devel unixODBC-devel
BuildPrereq: oracle-runtime ucd-snmp-devel glibc-devel cyrus-sasl-devel
BuildPrereq: zlib-devel autoconf
ExclusiveOS: linux

%description
The FreeRADIUS Server Project is a high-performance and
highly configurable RADIUS server. While the server is
conceptually similar to the Livingston server variants,
it has many more features, and is much more configurable.
It includes plug-in modules with support for MySQL,
PostgreSQL, Oracle, IODBC, IBM DB2, MS-SQL, Sybase, LDAP,
Kerberos, EAP, PAM, MS-CHAP and MPPE, Digest authentication,
Python, X9.9, and many more. It allows the administrator
to fully customize the behaviour of authentication,
accounting, and logging.


%package mysql
Group:       Development/Languages
Summary:     A MySQL database module for FreeRADIUS
Requires:    freeradius = %{version}-%{release} freeradius.pp
Requires:    mysql zlib
Provides:    freeradius-mysql.pp freeradius_database

%package pgsql
Group:       Development/Languages
Summary:     A PostgreSQL database module for FreeRADIUS
Requires:    freeradius = %{version}-%{release} freeradius.pp
Requires:    krb5-libs openssl postgresql-libs
Provides:    freeradius-pgsql.pp freeradius_database

%package odbc
Group:       Development/Languages
Summary:     An ODBC database module for FreeRADIUS
Requires:    freeradius = %{version}-%{release} freeradius.pp
Requires:    unixODBC
Provides:    freeradius-odbc.pp freeradius_database

%package oracle
Group:       Development/Languages
Summary:     An Oracle database module for FreeRADIUS
Requires:    freeradius = %{version}-%{release} freeradius.pp
Requires:    oracle-runtime
Provides:    freeradius-oracle.pp freeradius_database


%description mysql
The freeradius-mysql package contains a dynamic shared object
(DSO) for the FreeRADIUS Server. When compiled into FreeRADIUS
the mysql module will add MySQL database support to FreeRADIUS.
MySQL is an object-relational database management system. If
you need MySQL access, you will need to install this package.

%description pgsql
The freeradius-pgsql package contains a dynamic shared object
(DSO) for the FreeRADIUS Server. When compiled into FreeRADIUS
the pgsql module will add PostgreSQL database support to
FreeRADIUS. PostgreSQL is an object-relational database ma-
nagement system that supports almost all SQL constructs. If
you need PostgreSQL access, you will need to install this
package.

%description odbc
The freeradius-odbc package contains a dynamic shared object
(DSO) for the FreeRADIUS Server. When compiled into FreeRADIUS
the odbc module will add database support through ODBC to
FreeRADIUS. ODBC is an open specification which provides a
consistent API for developers to use for accessing data
sources (which are often, but not always, databases). If
you need ODBC access, you will need to install this package.

%description oracle
The freeradius-oracle package contains a dynamic shared object
(DSO) for the FreeRADIUS Server. When compiled into FreeRADIUS
the oracle module will add Oracle support to FreeRADIUS. If
you need Oracle access, you will need to install this package.


%prep
%setup -q -a1 -n %{name}-snapshot-%{radius_rev}
%patch0 -p1

# Reconfigure
WDIR=`pwd`
autoconf -l ${WDIR}
for dir in src/modules/rlm_eap/types/rlm_eap_peap \
	   src/modules/rlm_eap/types/rlm_eap_sim  \
	   src/modules/rlm_eap/types/rlm_eap_tls  \
	   src/modules/rlm_eap/types/rlm_eap_ttls \
	   src/modules/rlm_x99_token              \
	   src/modules/rlm_krb5; do
	pushd ${dir}
	autoconf -l ${WDIR}
	popd
done


%build
export CFLAGS="$RPM_OPT_FLAGS"

# Build OpenSSL >= 0.9.7
mkdir -p openssl-install/usr/lib
mkdir -p openssl-install/usr/include/openssl
pushd openssl-%{ssl_ver}

cp -fp Configure tmp_file
sed -e "s+-m486+$RPM_OPT_FLAGS+g" tmp_file > Configure
rm -f tmp_file

perl util/perlpath.pl /usr/bin/perl

./Configure \
	threads         \
	shared          \
	-DSSL_ALLOW_ADH \
	--prefix=/usr   \
	linux-elf
LD_LIBRARY_PATH=`pwd` make

cp libcrypto.a libradius-crypto.a
cp libssl.a libradius-ssl.a
make SHLIBDIRS="radius-crypto radius-ssl" do_linux-shared
make SHLIBDIRS="radius-crypto radius-ssl" link-shared

cp -d libradius* ../openssl-install/usr/lib
cp -L include/openssl/* ../openssl-install/usr/include/openssl

popd

# Build FreeRADIUS
./configure \
	--prefix=/usr                                             \
	--sysconfdir=/etc                                         \
	--localstatedir=/var                                      \
	--mandir=/usr/share/man                                   \
	--disable-ltdl-install                                    \
	--with-system-libtool                                     \
	--enable-shared                                           \
	--enable-static                                           \
	--with-ascend-binary                                      \
	--with-threads                                            \
	--with-thread-pool                                        \
	--with-snmp                                               \
	--with-large-files                                        \
	--with-rlm-sql_postgresql-include-dir=/usr/include/pgsql  \
	--with-rlm-krb5-include-dir=/usr/kerberos/include         \
	--with-rlm-krb5-lib-dir=/usr/kerberos/lib                 \
	--with-openssl-includes=`pwd`/openssl-install/usr/include \
	--with-openssl-libraries=`pwd`/openssl-install/usr/lib
make all


%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
mkdir -p $RPM_BUILD_ROOT/etc/pam.d
mkdir -p $RPM_BUILD_ROOT/usr
mkdir -p $RPM_BUILD_ROOT/var
make R=$RPM_BUILD_ROOT install
install -m 755 redhat/rc.radiusd-redhat $RPM_BUILD_ROOT/etc/rc.d/init.d/radiusd
install -m 644 redhat/radiusd-logrotate $RPM_BUILD_ROOT/etc/logrotate.d/radiusd
install -m 644 redhat/radiusd-pam       $RPM_BUILD_ROOT/etc/pam.d/radius
cp -d openssl-install/usr/lib/*         $RPM_BUILD_ROOT/usr/lib
install -m 644 raddb/eap*               $RPM_BUILD_ROOT/etc/raddb

RADDB=$RPM_BUILD_ROOT/etc/raddb
# set radiusd as default user/group
perl -i -pe 's/^#user =.*$/user = radiusd/' $RADDB/radiusd.conf
perl -i -pe 's/^#group =.*$/group = radiusd/' $RADDB/radiusd.conf
# shadow password file MUST be defined on Linux
perl -i -pe 's/#	shadow =/shadow =/' $RADDB/radiusd.conf


%pre
if ! grep "^radiusd" /etc/group > /dev/null 2>&1; then
   /usr/sbin/groupadd -g 95 radiusd > /dev/null 2>&1
fi 
if ! grep "^radiusd" /etc/passwd > /dev/null 2>&1; then
   /usr/sbin/useradd -u 95 -g radiusd -G radiusd -d /var/radiusd \
      -r -s /dev/null radiusd > /dev/null 2>&1
fi


%post
/sbin/ldconfig
for file in radius/radutmp radius/radwtmp radius/radius.log; do
   touch /var/log/$file
   chown radiusd:radiusd /var/log/$file
   chmod 600 /var/log/$file
done
chown radiusd:root /etc/raddb
/sbin/chkconfig --add radiusd
/sbin/chkconfig radiusd on
if [ -s /etc/raddb/radiusd.conf ]; then
   if [ -f /var/lock/subsys/radiusd ]; then
      /etc/rc.d/init.d/radiusd restart
   fi
fi


%preun
if [ $1 = 0 ] ; then
   /sbin/chkconfig radiusd off
   /sbin/chkconfig --del radiusd
   if [ -f /var/lock/subsys/radiusd ]; then
      /etc/rc.d/init.d/radiusd stop
   fi
fi


%postun
/sbin/ldconfig


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc COPYRIGHT CREDITS INSTALL LICENSE README
%doc %dir doc todo
%config /etc/logrotate.d/*
%config /etc/pam.d/*
%config /etc/rc.d/init.d/radiusd
%dir /etc/raddb
%config(noreplace) /etc/raddb/*
/usr/bin/*
/usr/sbin/*
%dir /usr/share/freeradius
%config /usr/share/freeradius/*
/usr/share/man/*
%attr(0700,radiusd,radiusd) %dir /var/log/radius
%attr(0700,radiusd,radiusd) %dir /var/log/radius/radacct
%attr(0700,radiusd,radiusd) %dir /var/run/radiusd
/usr/lib/libradius*
/usr/lib/rlm_acct_unique*
/usr/lib/rlm_always*
/usr/lib/rlm_attr*
/usr/lib/rlm_chap*
/usr/lib/rlm_counter*
/usr/lib/rlm_dbm*
/usr/lib/rlm_detail*
/usr/lib/rlm_digest*
/usr/lib/rlm_eap*
/usr/lib/rlm_exec*
/usr/lib/rlm_expr*
/usr/lib/rlm_fastusers*
/usr/lib/rlm_files*
/usr/lib/rlm_ippool*
/usr/lib/rlm_krb5*
/usr/lib/rlm_ldap*
/usr/lib/rlm_mschap*
/usr/lib/rlm_ns*
/usr/lib/rlm_pam*
/usr/lib/rlm_pap*
/usr/lib/rlm_preprocess*
/usr/lib/rlm_radutmp*
/usr/lib/rlm_realm*
/usr/lib/rlm_sql-*
/usr/lib/rlm_sql.*
/usr/lib/rlm_unix*
/usr/lib/rlm_x99*

%files mysql
%defattr(-,root,root)
/usr/lib/rlm_sql_mysql*

%files pgsql
%defattr(-,root,root)
/usr/lib/rlm_sql_postgresql*

%files odbc
%defattr(-,root,root)
/usr/lib/rlm_sql_unixodbc*

%files oracle
%defattr(-,root,root)
/usr/lib/rlm_sql_oracle*


%changelog
* Fri Mar 19 2004 peter.pramberger@1012surf.net
- new snapshot 0.9.3-20040318

* Fri Nov 28 2003 peter.pramberger@1012surf.net
- new snapshot 0.9.3-20031128 (security bugfixes)

* Sun Oct 05 2003 peter.pramberger@1012surf.net
- new snapshot 0.9.1-20031005

* Mon Sep 22 2003 peter.pramberger@1012surf.net
- EAP/TLS needs OpenSSL >= 0.9.7

* Sun Sep 21 2003 peter.pramberger@1012surf.net
- created

